@@ -3,6 +3,7 @@ from typing import Optional
 
 from lxml import etree
 from pydantic import BaseModel, validator
+from unidecode import unidecode
 
 from spei import types
 from spei.utils import to_snake_case, to_upper_camel_case  # noqa: WPS347
@@ -175,7 +176,7 @@ class Orden(BaseModel):
             tag = to_snake_case(element.tag)
             if tag in cls.__fields__:
                 if element.text:
-                    orden_data[tag] = element.text.strip()
+                    orden_data[tag] = unidecode(element.text.strip())
                 else:
                     orden_data[tag] = None
             if tag == 'op_ins_clave':
