@@ -1,3 +1,5 @@
+from typing import Optional, TypedDict
+
 from lxml import etree
 from pydantic import BaseModel
 
@@ -5,12 +7,20 @@ from spei import types
 from spei.utils import to_snake_case, to_upper_camel_case  # noqa: WPS347
 
 
-class Respuesta(BaseModel):
-    id: str
-    fecha_oper: int
-    err_codigo: types.CodigoError
-    err_descripcion: str
+class DataDict(TypedDict, total=False):
     categoria: types.CategoriaOrdenPago
+    id: Optional[str]
+    fecha_oper: Optional[int]
+    err_codigo: Optional[types.CodigoError]
+    err_descripcion: Optional[str]
+
+
+class Respuesta(BaseModel):
+    err_codigo: types.CodigoError
+    categoria: types.CategoriaOrdenPago
+    id: Optional[str]
+    fecha_oper: Optional[int]
+    err_descripcion: Optional[str]
 
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
@@ -28,12 +38,12 @@ class Respuesta(BaseModel):
 
     @classmethod
     def parse_xml(cls, respuesta_element, categoria: types.CategoriaOrdenPago):
-        respuesta_data = {
+        respuesta_data: DataDict = {
             'categoria': categoria,
         }
 
         for sub_element in respuesta_element.getchildren():
             tag = to_snake_case(sub_element.tag)
-            respuesta_data[tag] = sub_element.text
+            respuesta_data[tag] = sub_element.text  # type: ignore
 
         return cls(**respuesta_data)
